@@ -1,5 +1,3 @@
-from bs4 import BeautifulSoup
-
-def apply_rules(doc):
+def rm_templates(doc):
     for el in doc.find_all("template"):
         el.extract()
